# Generated by Django 4.2.21 on 2025-05-09 13:51

# Django
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("fortunaisk", "0004_consolidate_ticketpurchases"),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name="ticketpurchase",
            name="unique_ticketpurchase_per_user_character",
        ),
    ]
