# fortunaisk/templates/fortunaisk/terminate_lottery_confirm.html -->
{% extends "fortunaisk/base.html" %}
{% load i18n static %}

{% block page_title %}
    {% trans "Terminate Lottery" %}
{% endblock page_title %}

{% block details %}
<div class="container my-5">
    <div class="row justify-content-center">
        <div class="col-md-6">
            <!-- Card for Terminating Lottery -->
            <div class="card shadow-lg border-0">
                <div class="card-header text-white" style="background: linear-gradient(135deg, #e74c3c, #c0392b);">
                    <h4 class="mb-0">
                        <i class="fas fa-times-circle me-2"></i>
                        {% trans "Terminate Lottery" %}: {{ lottery.lottery_reference }}
                    </h4>
                </div>
                <div class="card-body">
                    <div class="alert alert-danger" role="alert">
                        <i class="fas fa-exclamation-triangle me-2"></i>
                        {% trans "Are you sure you want to terminate this lottery prematurely? This action cannot be undone." %}
                    </div>
                    <form method="post">
                        {% csrf_token %}
                        <div class="d-flex justify-content-between">
                            <a href="{% url 'fortunaisk:admin_dashboard' %}" class="btn btn-outline-secondary">
                                <i class="fas fa-arrow-left me-1"></i>{% trans "Cancel" %}
                            </a>
                            <button type="submit" class="btn btn-danger">
                                <i class="fas fa-times me-1"></i>{% trans "Yes, Terminate" %}
                            </button>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
</div>
{% endblock details %}
